@@ -10,31 +10,40 @@ import os
 import os.path
 import sys
 import asyncio
-from argparse import ArgumentParser, Namespace
-from ssl import create_default_context, CERT_NONE, SSLContext
+from argparse import ArgumentParser, Namespace, SUPPRESS
+from ssl import create_default_context, CERT_NONE
 from typing import Type, Optional
 
 from grpclib.client import Channel
 from pymapadmin import __version__
 
+from .commands import load_commands
+from .commands.base import Command
+from .config import Config
 from .local import get_admin_socket
-from .commands import Command
-from .commands.load import load_commands
 
 
 def main() -> int:
     parser = ArgumentParser(description=__doc__)
     parser.add_argument('--version', action='version',
                         version='%(prog)s' + __version__)
+    parser.add_argument('--config', metavar='PATH', type=Config,
+                        default=_def('CONFIG', '~/.pymaprc'),
+                        help='configuration file path')
     parser.add_argument('--host', metavar='HOST',
                         default=_def('HOST'), help='server host')
-    parser.add_argument('--port', metavar='PORT', type=int,
+    parser.add_argument('--port', metavar='PORT',
                         default=_def('PORT'), help='server port')
-    parser.set_defaults(path=get_admin_socket())
+    parser.add_argument('--path', metavar='FILE',
+                        default=_def('PATH'), help=SUPPRESS)
+    parser.add_argument('--token', metavar='STR', default=_def('TOKEN'),
+                        help='auth token')
 
     group = parser.add_argument_group('tls options')
-    group.add_argument('--tls', action='store_true', default=_def('TLS'),
-                       help='enable TLS')
+    group.add_argument('--cert', metavar='FILE', default=_def('CERT'),
+                       help='client certificate')
+    group.add_argument('--key', metavar='FILE', default=_def('KEY'),
+                       help='client private key')
     group.add_argument('--cafile', metavar='FILE', default=_def('CAFILE'),
                        help='CA cert file')
     group.add_argument('--capath', metavar='PATH', default=_def('CAPATH'),
@@ -42,14 +51,6 @@ def main() -> int:
     group.add_argument('--no-verify-cert', action='store_true',
                        help='skip TLS certificate verification')
 
-    group = parser.add_argument_group('auth options')
-    group.add_argument('--username', metavar='NAME', dest='admin_username',
-                       default=_def('USERNAME'), help='auth username')
-    group.add_argument('--password', metavar='PASS', dest='admin_password',
-                       default=_def('PASSWORD'), help='auth password')
-    group.add_argument('--ask-password', action='store_true',
-                       help='prompt for the auth password')
-
     subparsers = parser.add_subparsers(dest='command', metavar='COMMAND')
     commands = load_commands('pymapadmin.commands')
     for command_name, command_cls in commands.items():
@@ -65,22 +66,16 @@ def main() -> int:
 
 async def run(parser: ArgumentParser, args: Namespace,
               command_cls: Type[Command]) -> int:
-    ssl: Optional[SSLContext] = None
-    if args.tls:
-        ssl = create_default_context(cafile=args.cafile, capath=args.capath)
-        if args.no_verify_cert:
-            ssl.check_hostname = False
-            ssl.verify_mode = CERT_NONE
-    if args.host is None:
-        if not os.path.exists(args.path):
-            parser.error(f'File not found: {args.path}\n\n'
-                         f'Is pymap running? Use --host to connect to a '
-                         f'remote host.')
-        channel = Channel(path=args.path)
-    else:
+    ssl = create_default_context(cafile=args.cafile, capath=args.capath)
+    if args.no_verify_cert:
+        ssl.check_hostname = False
+        ssl.verify_mode = CERT_NONE
+    if args.host is not None or args.port is not None:
         channel = Channel(host=args.host, port=args.port, ssl=ssl)
-    client = command_cls.get_client(channel)
-    command = command_cls(args, client)
+    else:
+        path = args.path or get_admin_socket()
+        channel = Channel(path=path)
+    command = command_cls(args, channel)
     try:
         return await command(sys.stdout)
     finally:
